<p align="center" width="100%">
    <img src="https://raw.githubusercontent.com/invalidkaro/pyblox/main/docs/assets/textlogo.svg" alt="pyblox" height="128em" />
    <br />
</p>
<p align="center">
    <a href="https://github.com/invalidkaro/pyblox">GitHub</a> |
    <a href="https://discord.gg/">Discord</a> |
    <a href="https://pypi.org/project/py3bloxx/">PyPI</a> |
    <a href="https://pyblox-docs.invalidkaro.dev">Documentation</a> |
    <a href="https://github.com/invalidkaro/pyblox/tree/main/examples">Examples</a> |
    <a href="https://github.com/invalidkaro/pyblox/blob/main/LICENSE">License</a>
    <a href="mailto:mail@invalidkaro.dev">Write a mail</a>
</p>
<p align="center">
    <a href="https://discord.gg/"><img src="https://img.shields.io/discord/761603917490159676?style=flat-square&logo=discord" alt=""/></a>
    <a href="https://pypi.org/project/py3bloxx/"><img src="https://img.shields.io/pypi/v/py3bloxx?style=flat-square" alt="pyblox PyPI"/></a>
    <a href="https://pypi.org/project/py3bloxx/"><img src="https://img.shields.io/pypi/dm/py3bloxx?style=flat-square" alt="pyblox PyPI Downloads"/></a>
    <a href="https://pypi.org/project/py3bloxx/"><img src="https://img.shields.io/pypi/dm/py3bloxx?style=flat-square" alt="pyblox PyPI Downloads (Legacy)"/></a>
    <a href="https://pypi.org/project/py3bloxx/"><img src="https://img.shields.io/pypi/l/py3bloxx?style=flat-square" alt="pyblox PyPI License"/></a>
    <a href="https://github.com/invalidkaro/pyblox"><img src="https://img.shields.io/github/commit-activity/w/InvalidKaro/pyblox?style=flat-square" alt="pyblox GitHub Commit Activity"/></a>
    <a href="https://github.com/invalidkaro/pyblox"><img src="https://img.shields.io/github/last-commit/invalidkaro/pyblox?style=flat-squar" alt="pyblox GitHub Last Commit"/></a>
</p>

# Overview
Welcome to pyblox! pyblox is an asynchronous, object-oriented wrapper for the Roblox web API.

# Features
The key features are:  

- **Asynchronous**: pyblox works well with asynchronous frameworks like [FastAPI](https://fastapi.tiangolo.com/) and 
[discord.py](https://github.com/Rapptz/discord.py).  
- **Easy**: pyblox's client-based model is intuitive and easy to learn for both the beginner and expert developer. It
  abstracts away API requests and leaves you with simple objects that represent data types on the Roblox platform.
- **Flexible**: pyblox's builtin Requests object allows the user to do things that we haven't already implemented
ourselves without dealing with advanced Roblox-specific concepts.

# Installation
To install pyblox from PyPI, you can install with pip:
```
pip install py3bloxx
```

To install the latest unstable version of pyblox, install [git-scm](https://git-scm.com/downloads) and run the following:
```
pip install git+https://github.com/invalidkaro/pyblox.git
```

# Tutorial
Learn how to use pyblox in our docs:
https://https://pyblox-docs.invalidkaro.dev/dev/tutorial/
